@@ -103,6 +103,21 @@ class LeadsClient(BaseClient):
                 (len(leads), guids and 'guids=%s, '%guids or '', original_options))
         return leads
 
+    def retrieve_lead(self, *guid, **options):
+        cur_guid = guid or '' 
+        params = {}
+        for key in options:
+            params[key] = options[key]
+        """ Set guid to -1 as default for not finding a user """
+        lead = {'guid' : '-1'}
+        """ wrap lead call so that it doesn't error out when not finding a lead """
+        try:
+            lead = self._call('lead/%s' % cur_guid, params, **options)
+        except:
+            """ no lead here """
+        return lead
+
+
     def update_lead(self, guid, update_data=None, **options):
         update_data = update_data or {}
         update_data['guid'] = guid
